import json
from json import JSONDecodeError


class JsonUtils:

    @staticmethod
    def is_valid_json(json_str):
        try:
            json.loads(json_str)
            return True
        except JSONDecodeError:
            return False

    @staticmethod
    def has_keys(json_str, keys: list[str]) -> bool:
        try:
            json_obj = json.loads(json_str)
            for key in keys:
                if key not in json_obj:
                    return False
            return True
        except JSONDecodeError:
            return False




import ffmpeg


class VideoUtils:

    @staticmethod
    def extract_audio(video_path, audio_path):
        # Estrae solo la traccia audio dal video
        ffmpeg.input(video_path).output(audio_path).run(overwrite_output=True)




# log_config.py
from loguru import logger

# Disattiva tutti i log all'inizio
logger.remove()



def enable_logging(level="DEBUG", file_path=None, to_stdout=True):
    """Abilita il logging con il livello e il percorso file opzionali."""

    # Log su file
    if file_path:
        logger.add(
            file_path,
            level=level,
            format="{time} {level} {message}",
            rotation="10 MB",
            compression="zip",
            serialize=False
        )

    # Log su stdout
    if to_stdout:
        logger.add(
            lambda msg: print(msg, end=""),  # Stampare direttamente a stdout
            level=level,
            format="{time} {level} {message}"
        )

    logger.info("Logging abilitato per la libreria.")


def test_logging():
    logger.debug("This is a debug message")
    logger.info("This is an info message")
    logger.warning("This is a warning message")
    logger.error("This is an error message")
    logger.critical("This is a critical message")